@@ -1,10 +1,11 @@
-from typing import Union, Optional
+from typing import Union
 
 import graphql
 from jinja2 import Environment, PackageLoader, select_autoescape
-from .configs import default_config
+
 from . import filters
 from . import utilities
+from .configs import default_config
 
 _template_name = 'graphql-docs.html'
 _jinja_env = Environment(
