@@ -47,11 +47,22 @@ def build_types_reference(
 
     # separate the different type definitions in the schema
     reference = definitions.TypeMapReference()
-    reference.query = schema.query_type
-    reference.mutation = schema.mutation_type
+    if hasattr(schema, 'query_type') and hasattr(schema, 'mutation_type'):
+        # graphql-core>=3.1.0,<4
+        reference.query = schema.query_type
+        reference.mutation = schema.mutation_type
+    else:
+        # graphql-core>=2.1.0,<3
+        reference.query = schema.get_query_type()
+        reference.mutation = schema.get_mutation_type()
+
     if reference.mutation:
         for name, field in reference.mutation.fields.items():
-            setattr(field, 'unwrapped_type', unwrap_field_type(field.type))
+            # Wrap all mutation fields to set the unwrapped_field attr
+            unwrapped_field = unwrap_field_type(field.type)
+            wrapper = definitions.GraphQLField(field)
+            wrapper.unwrapped_field = unwrapped_field
+            reference.mutation.fields[name] = wrapper
 
     implemented_by = defaultdict(list)
     for name, obj in type_map.items():
